%global rpmrelease 2
%global debianpatchrelease 3.1.21-4
# beta is either 0 or something like beta1
%global beta 0

# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
%else
  %global _servicefile_postfix init
%endif

%global _has_inotify %([ -e %{_includedir}/sys/inotify.h ] && echo 1 || echo 0)

Summary: Tools to send and receive short messages through GSM modems or mobile phones
Name: smstools
Version: 3.1.21
%if "%{beta}" == "0"
Release: %{rpmrelease}%{?dist}
%else
Release: 0.%{beta}_%{rpmrelease}%{?dist}
%endif
License: GPL-2.0-or-later
Group: Applications/Communications
URL: http://smstools3.kekekasvi.com/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
%if "%{beta}" == "0"
Source0: http://smstools3.kekekasvi.com/packages/smstools3-%{version}.tar.gz
%else
Source0: http://smstools3.kekekasvi.com/packages/smstools3-%{version}%{beta}.tar.gz
%endif
Source1: smsd.%{_servicefile_postfix}
Source2: smsd.conf
Source3: http://ftp.de.debian.org/debian/pool/main/s/smstools/smstools_%{debianpatchrelease}.debian.tar.gz
Patch0: smstools3-3.1.15-typo.patch
BuildRequires: glibc-headers
%if %{_has_systemd}
Patch1: smstools3-3.1.15-systemd_rundir.patch
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
Requires(pre): %{_sbindir}/groupadd
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
The SMS Server Tools are made to send and receive short messages
through GSM modems. It supports easy file interfaces and it can run
external programs for automatic actions.

%prep
%setup -q -a 3 -n smstools3
%patch0 -p1 -b .typo
%if %{_has_systemd}
%patch1 -p1 -b .systemd_rundir
%endif

# apply only the debian patches we really want
for I in fix-makefile-override hardening spelling enable-statistics; do
  %{__mv} -vf "debian/patches/${I}.patch" "debian/patches/${I}.patch.disabled"
done
for I in debian/patches/*.patch; do
  if [ -f "$I" ]; then
    %{__patch} -p1 < "$I"
  fi
done

%{__mv} doc manual
%{__mv} examples/.procmailrc examples/procmailrc
%{__mv} examples/.qmailrc examples/qmailrc
find LICENSE scripts/ examples/ manual/ -type f -exec %{__chmod} 0644 {} \;

%build
%if ! %{_has_inotify}
  CFLAGS="-D DISABLE_INOTIFY"
%endif

%{__make} -C src CFLAGS="%{optflags} -D NOSTATS -D NUMBER_OF_MODEMS=64 -D _FILE_OFFSET_BITS=64 -D USE_LINUX_PS_TRICK $CFLAGS"

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}
%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_sbindir}
%{__install} -d %{buildroot}%{_var}/spool/sms
%{__install} -d %{buildroot}%{_mandir}/man8

%{__install} -m 0700 -d %{buildroot}%{_var}/spool/sms/checked
%{__install} -m 0700 -d %{buildroot}%{_var}/spool/sms/failed
%{__install} -m 0700 -d %{buildroot}%{_var}/spool/sms/incoming
%{__install} -m 0700 -d %{buildroot}%{_var}/spool/sms/outgoing
%{__install} -m 0700 -d %{buildroot}%{_var}/spool/sms/stage
%{__install} -m 0700 -d %{buildroot}%{_var}/spool/sms/sent

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/smsd.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/smsd
%endif

%{__install} -m 0600 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/smsd.conf
%{__install} -m 0755 -p scripts/sendsms %{buildroot}%{_bindir}/smssend
%{__install} -m 0755 -p scripts/sms2html %{buildroot}%{_bindir}/
%{__install} -m 0755 -p scripts/sms2unicode %{buildroot}%{_bindir}/
%{__install} -m 0755 -p scripts/sms2xml %{buildroot}%{_bindir}/
%{__install} -m 0755 -p scripts/unicode2sms %{buildroot}%{_bindir}/
%{__install} -m 0755 -p src/smsd %{buildroot}%{_sbindir}/
%{__install} -m 0644 -p debian/smsd.8 %{buildroot}%{_mandir}/man8/

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{name} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post smsd.service
%else
/sbin/chkconfig --add smsd
%endif

%preun
%if %{_has_systemd}
%systemd_preun smsd.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service smsd stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del smsd
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart smsd.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service smsd condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE manual/ examples/ scripts/checkhandler-utf-8 scripts/email2sms scripts/eventhandler-utf-8
%doc scripts/mysmsd scripts/regular_run scripts/smsevent scripts/smsresend scripts/sql_demo
%if %{_has_systemd}
%{_unitdir}/smsd.service
%else
%config %{_initrddir}/smsd
%endif
%config(noreplace) %{_sysconfdir}/smsd.conf
%{_bindir}/*
%{_sbindir}/*
%attr(0755,root,root) %dir %{_var}/spool/sms
%attr(0700,root,root) %dir %{_var}/spool/sms/checked
%attr(0700,root,root) %dir %{_var}/spool/sms/failed
%attr(0700,root,root) %dir %{_var}/spool/sms/incoming
%attr(0730,root,%{name}) %dir %{_var}/spool/sms/outgoing
%attr(0730,root,%{name}) %dir %{_var}/spool/sms/stage
%attr(0700,root,root) %dir %{_var}/spool/sms/sent
%{_mandir}/man8/sms*.8*

%changelog
* Wed May 17 2023 Simon Matter <simon.matter@invoca.ch> 3.1.21-2
- update Debian patchset
- change license tag to SPDX style
- add support for EL >= 8

* Thu May 04 2017 Simon Matter <simon.matter@invoca.ch> 3.1.21-1
- upgrade to 3.1.21

* Thu Apr 13 2017 Simon Matter <simon.matter@invoca.ch> 3.1.20-2
- cosmetic spec files changes

* Wed Apr 12 2017 Simon Matter <simon.matter@invoca.ch> 3.1.20-1
- upgrade to 3.1.20
- update debian patches

* Sat Mar 11 2017 Simon Matter <simon.matter@invoca.ch> 3.1.19-1
- upgrade to 3.1.19

* Mon Mar 06 2017 Simon Matter <simon.matter@invoca.ch> 3.1.18-1
- upgrade to 3.1.18

* Mon Feb 27 2017 Simon Matter <simon.matter@invoca.ch> 3.1.17-1
- upgrade to 3.1.17

* Fri Feb 10 2017 Simon Matter <simon.matter@invoca.ch> 3.1.16-1
- upgrade to 3.1.16
- update debian patch

* Wed May 27 2015 Simon Matter <simon.matter@invoca.ch> 3.1.15-4
- add support for systemd

* Sat Nov 09 2013 Simon Matter <simon.matter@invoca.ch> 3.1.15-3
- add typo patch
- update debian patch

* Sat Oct 19 2013 Simon Matter <simon.matter@invoca.ch> 3.1.15-2
- change default config
- add USE_LINUX_PS_TRICK build option
- update debian patch

* Mon Oct 22 2012 Simon Matter <simon.matter@invoca.ch> 3.1.15-1
- upgrade to 3.1.15

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 3.1.14-2
- mass rebuild

* Wed Sep 22 2010 Simon Matter <simon.matter@invoca.ch> 3.1.14-1
- upgrade to 3.1.14

* Fri Sep 03 2010 Simon Matter <simon.matter@invoca.ch> 3.1.12-1
- upgrade to 3.1.12

* Mon Jun 21 2010 Simon Matter <simon.matter@invoca.ch> 3.1.11-1
- upgrade to 3.1.11

* Sun Jun 20 2010 Simon Matter <simon.matter@invoca.ch> 3.1.10-1
- upgrade to 3.1.10

* Fri Jun 18 2010 Simon Matter <simon.matter@invoca.ch> 3.1.9-1
- upgrade to 3.1.9
- add stage directory

* Thu May 06 2010 Simon Matter <simon.matter@invoca.ch> 3.1.8-1
- upgrade to 3.1.8

* Mon May 03 2010 Simon Matter <simon.matter@invoca.ch> 3.1.7-1
- upgrade to 3.1.7

* Wed Dec 02 2009 Simon Matter <simon.matter@invoca.ch> 3.1.6-1
- upgrade to 3.1.6

* Mon Jun 01 2009 Simon Matter <simon.matter@invoca.ch> 3.1.5-1
- upgrade to 3.1.5

* Sat May 16 2009 Simon Matter <simon.matter@invoca.ch> 3.1.5-0.beta9_1
- upgrade to 3.1.5beta9
- add syslog_progname patch

* Sat May 16 2009 Simon Matter <simon.matter@invoca.ch> 3.1.3-4
- add patches from debian (manpage)
- remove logrotate config
- add our own smsd.conf which logs to syslog by default

* Mon Feb 16 2009 Simon Matter <simon.matter@invoca.ch> 3.1.3-3
- fix group ownership and permissions on outgoing directory
- fix post install scripts

* Sun Feb 15 2009 Simon Matter <simon.matter@invoca.ch> 3.1.3-1
- initial package
